# libpythonpro

Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)
[![Build Status](https://travis-ci.com/leandromartins36/libpythonpro.svg?branch=master)](https://travis-ci.com/leandromartins36/libpythonpro)
[![Build Status](https://travis-ci.org/pythonprobr/libpythonpro.svg?branch=master)](https://travis-ci.org/pythonprobr/libpythonpro)
[![Updates](https://pyup.io/repos/github/pythonprobr/libpythonpro/shield.svg)](https://pyup.io/repos/github/pythonprobr/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/pythonprobr/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/pythonprobr/libpythonpro/)
[![codecov](https://codecov.io/gh/pythonprobr/libpythonpro/branch/master/graph/badge.svg)](https://codecov.io/gh/pythonprobr/libpythonpro)

Suportada versão 3 de Python

Para instalar:

```console
pip install pipenv
pipenv install --dev
python3 -m venv .venv
source .venv/bin/activate
```

Para conferir qualidade de código:

```console
flake8
pipenv run flake8
```

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
 4. Mock
 5. Pipenv

 
